@@ -108,7 +108,7 @@ class UseTestCase(unittest.TestCase):
         self.assertEqual(cron.render(), '')
 
     def test_06_touser(self):
-        """Write to use API"""
+        """Write to user API"""
         cron = crontab.CronTab(tab=USER)
         self.assertEqual(repr(cron), "<Unattached CronTab>")
         cron.write_to_user('bob')
@@ -117,6 +117,16 @@ class UseTestCase(unittest.TestCase):
         self.assertTrue(os.path.exists(filename))
         self.assertEqual(repr(cron), "<User CronTab 'bob'>")
 
+    def test_06_touser_fail(self):
+        """Write to user failed"""
+        cron = crontab.CronTab(tab=USER)
+        self.assertRaises(IOError, cron.write_to_user, 'john')
+        filename = os.path.join(TEST_DIR, 'data', 'spool', 'john')
+        if os.path.exists(filename):
+            os.unlink(filename)
+            self.assertTrue(filename)
+
+
     def test_07_ioerror_read(self):
         """No filename ioerror"""
         with self.assertRaises(IOError):
